@@ -1,23 +1,12 @@
 from django.conf.urls import patterns, url
+from django.contrib.auth.views import (login, logout, password_change,
+                                       password_change_done, password_reset,
+                                       password_reset_complete,
+                                       password_reset_confirm,
+                                       password_reset_done)
 
-from django.contrib.auth.views import (
-    login,
-    logout,
-    password_change,
-    password_change_done,
-    password_reset,
-    password_reset_done,
-    password_reset_confirm,
-    password_reset_complete
-)
-
-from .views import (
-    register,
-    registration_closed,
-    registration_complete,
-    activate,
-    activation_complete,
-)
+from .views import (activate, activation_complete, register,
+                    registration_closed, registration_complete)
 
 urlpatterns = patterns(
     '',
